<?php
header('Content-Type: application/json');


$dataFile = 'your-json-file-for-playerdata.json';


function generateToken() {
    return bin2hex(random_bytes(16));
}

function loadPlayersData() {
    global $dataFile;
    
    if (file_exists($dataFile)) {
        $data = file_get_contents($dataFile);
        return json_decode($data, true) ?: [];
    }
    
    return [];
}

function savePlayersData($data) {
    global $dataFile;
    file_put_contents($dataFile, json_encode($data, JSON_PRETTY_PRINT));
}


function verifyToken($nick, $token) {
    $players = loadPlayersData();
    
    if (isset($players[$nick]) && $players[$nick]['private_token'] === $token) {
        return true;
    }
    
    return false;
}


$method = $_SERVER['REQUEST_METHOD'];


if ($method === 'POST') {

    $postData = json_decode(file_get_contents('php://input'), true);
    

    if (!isset($postData['nick']) || !isset($postData['last_time_online']) || !isset($postData['online'])) {
        http_response_code(400);
        echo json_encode(['error' => 'Missing required fields']);
        exit;
    }
    

    $players = loadPlayersData();
    

    $nick = $postData['nick'];
    $token = generateToken();
    

    $server = isset($postData['server']) ? $postData['server'] : 'main';
    
    $players[$nick] = [
        'nick' => $nick,
        'last_time_online' => $postData['last_time_online'],
        'online' => $postData['online'],
        'private_token' => $token,
        'server' => $server
    ];
    

    savePlayersData($players);
    

    echo json_encode(['token' => $token]);
} elseif ($method === 'GET') {

    $players = loadPlayersData();
    
    if (isset($_GET['token'])) {
        $token = $_GET['token'];
        $playerFound = false;
        
        foreach ($players as $nick => $player) {
            if ($player['private_token'] === $token) {
                $playerData = [
                    'nick' => $player['nick'],
                    'last_time_online' => $player['last_time_online'],
                    'online' => $player['online'],
                    'server' => $player['server']
                ];
                
                echo json_encode($playerData);
                $playerFound = true;
                break;
            }
        }
        
        if (!$playerFound) {
            http_response_code(404);
            echo json_encode(['error' => 'Invalid token']);
        }
        
        exit;
    }
    
    $nick = isset($_GET['nick']) ? $_GET['nick'] : null;
    
    if (!$nick) {
        http_response_code(400);
        echo json_encode(['error' => 'Missing nick parameter']);
        exit;
    }
    
    if (!isset($players[$nick])) {
        http_response_code(404);
        echo json_encode(['error' => 'Player not found']);
        exit;
    }
    
    $playerData = [
        'nick' => $players[$nick]['nick'],
        'last_time_online' => $players[$nick]['last_time_online'],
        'online' => $players[$nick]['online']
    ];
    
    if (isset($_GET['token']) && $players[$nick]['private_token'] === $_GET['token']) {
        $playerData['server'] = $players[$nick]['server'];
    }
    
    echo json_encode($playerData);
} else {
    http_response_code(405);
    echo json_encode(['error' => 'Method not allowed']);
}
